# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilitySimulationJobConfigDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'sender_inbox_id': 'str',
        'sender_phone_id': 'str',
        'email_subject': 'str',
        'email_from_override': 'str',
        'email_body_template': 'str',
        'sms_body_template': 'str',
        'delay_ms': 'int',
        'batch_size': 'int',
        'sends_per_target': 'int'
    }

    attribute_map = {
        'sender_inbox_id': 'senderInboxId',
        'sender_phone_id': 'senderPhoneId',
        'email_subject': 'emailSubject',
        'email_from_override': 'emailFromOverride',
        'email_body_template': 'emailBodyTemplate',
        'sms_body_template': 'smsBodyTemplate',
        'delay_ms': 'delayMs',
        'batch_size': 'batchSize',
        'sends_per_target': 'sendsPerTarget'
    }

    def __init__(self, sender_inbox_id=None, sender_phone_id=None, email_subject=None, email_from_override=None, email_body_template=None, sms_body_template=None, delay_ms=None, batch_size=None, sends_per_target=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilitySimulationJobConfigDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._sender_inbox_id = None
        self._sender_phone_id = None
        self._email_subject = None
        self._email_from_override = None
        self._email_body_template = None
        self._sms_body_template = None
        self._delay_ms = None
        self._batch_size = None
        self._sends_per_target = None
        self.discriminator = None

        self.sender_inbox_id = sender_inbox_id
        self.sender_phone_id = sender_phone_id
        self.email_subject = email_subject
        self.email_from_override = email_from_override
        self.email_body_template = email_body_template
        self.sms_body_template = sms_body_template
        self.delay_ms = delay_ms
        self.batch_size = batch_size
        self.sends_per_target = sends_per_target

    @property
    def sender_inbox_id(self):
        """Gets the sender_inbox_id of this DeliverabilitySimulationJobConfigDto.  # noqa: E501


        :return: The sender_inbox_id of this DeliverabilitySimulationJobConfigDto.  # noqa: E501
        :rtype: str
        """
        return self._sender_inbox_id

    @sender_inbox_id.setter
    def sender_inbox_id(self, sender_inbox_id):
        """Sets the sender_inbox_id of this DeliverabilitySimulationJobConfigDto.


        :param sender_inbox_id: The sender_inbox_id of this DeliverabilitySimulationJobConfigDto.  # noqa: E501
        :type: str
        """

        self._sender_inbox_id = sender_inbox_id

    @property
    def sender_phone_id(self):
        """Gets the sender_phone_id of this DeliverabilitySimulationJobConfigDto.  # noqa: E501


        :return: The sender_phone_id of this DeliverabilitySimulationJobConfigDto.  # noqa: E501
        :rtype: str
        """
        return self._sender_phone_id

    @sender_phone_id.setter
    def sender_phone_id(self, sender_phone_id):
        """Sets the sender_phone_id of this DeliverabilitySimulationJobConfigDto.


        :param sender_phone_id: The sender_phone_id of this DeliverabilitySimulationJobConfigDto.  # noqa: E501
        :type: str
        """

        self._sender_phone_id = sender_phone_id

    @property
    def email_subject(self):
        """Gets the email_subject of this DeliverabilitySimulationJobConfigDto.  # noqa: E501


        :return: The email_subject of this DeliverabilitySimulationJobConfigDto.  # noqa: E501
        :rtype: str
        """
        return self._email_subject

    @email_subject.setter
    def email_subject(self, email_subject):
        """Sets the email_subject of this DeliverabilitySimulationJobConfigDto.


        :param email_subject: The email_subject of this DeliverabilitySimulationJobConfigDto.  # noqa: E501
        :type: str
        """

        self._email_subject = email_subject

    @property
    def email_from_override(self):
        """Gets the email_from_override of this DeliverabilitySimulationJobConfigDto.  # noqa: E501


        :return: The email_from_override of this DeliverabilitySimulationJobConfigDto.  # noqa: E501
        :rtype: str
        """
        return self._email_from_override

    @email_from_override.setter
    def email_from_override(self, email_from_override):
        """Sets the email_from_override of this DeliverabilitySimulationJobConfigDto.


        :param email_from_override: The email_from_override of this DeliverabilitySimulationJobConfigDto.  # noqa: E501
        :type: str
        """

        self._email_from_override = email_from_override

    @property
    def email_body_template(self):
        """Gets the email_body_template of this DeliverabilitySimulationJobConfigDto.  # noqa: E501


        :return: The email_body_template of this DeliverabilitySimulationJobConfigDto.  # noqa: E501
        :rtype: str
        """
        return self._email_body_template

    @email_body_template.setter
    def email_body_template(self, email_body_template):
        """Sets the email_body_template of this DeliverabilitySimulationJobConfigDto.


        :param email_body_template: The email_body_template of this DeliverabilitySimulationJobConfigDto.  # noqa: E501
        :type: str
        """

        self._email_body_template = email_body_template

    @property
    def sms_body_template(self):
        """Gets the sms_body_template of this DeliverabilitySimulationJobConfigDto.  # noqa: E501


        :return: The sms_body_template of this DeliverabilitySimulationJobConfigDto.  # noqa: E501
        :rtype: str
        """
        return self._sms_body_template

    @sms_body_template.setter
    def sms_body_template(self, sms_body_template):
        """Sets the sms_body_template of this DeliverabilitySimulationJobConfigDto.


        :param sms_body_template: The sms_body_template of this DeliverabilitySimulationJobConfigDto.  # noqa: E501
        :type: str
        """

        self._sms_body_template = sms_body_template

    @property
    def delay_ms(self):
        """Gets the delay_ms of this DeliverabilitySimulationJobConfigDto.  # noqa: E501


        :return: The delay_ms of this DeliverabilitySimulationJobConfigDto.  # noqa: E501
        :rtype: int
        """
        return self._delay_ms

    @delay_ms.setter
    def delay_ms(self, delay_ms):
        """Sets the delay_ms of this DeliverabilitySimulationJobConfigDto.


        :param delay_ms: The delay_ms of this DeliverabilitySimulationJobConfigDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and delay_ms is None:  # noqa: E501
            raise ValueError("Invalid value for `delay_ms`, must not be `None`")  # noqa: E501

        self._delay_ms = delay_ms

    @property
    def batch_size(self):
        """Gets the batch_size of this DeliverabilitySimulationJobConfigDto.  # noqa: E501


        :return: The batch_size of this DeliverabilitySimulationJobConfigDto.  # noqa: E501
        :rtype: int
        """
        return self._batch_size

    @batch_size.setter
    def batch_size(self, batch_size):
        """Sets the batch_size of this DeliverabilitySimulationJobConfigDto.


        :param batch_size: The batch_size of this DeliverabilitySimulationJobConfigDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and batch_size is None:  # noqa: E501
            raise ValueError("Invalid value for `batch_size`, must not be `None`")  # noqa: E501

        self._batch_size = batch_size

    @property
    def sends_per_target(self):
        """Gets the sends_per_target of this DeliverabilitySimulationJobConfigDto.  # noqa: E501


        :return: The sends_per_target of this DeliverabilitySimulationJobConfigDto.  # noqa: E501
        :rtype: int
        """
        return self._sends_per_target

    @sends_per_target.setter
    def sends_per_target(self, sends_per_target):
        """Sets the sends_per_target of this DeliverabilitySimulationJobConfigDto.


        :param sends_per_target: The sends_per_target of this DeliverabilitySimulationJobConfigDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and sends_per_target is None:  # noqa: E501
            raise ValueError("Invalid value for `sends_per_target`, must not be `None`")  # noqa: E501

        self._sends_per_target = sends_per_target

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilitySimulationJobConfigDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilitySimulationJobConfigDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DomainMonitorSummaryDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'monitor': 'DomainMonitorDto',
        'latest_run': 'DomainMonitorRunDto',
        'insights': 'DomainMonitorInsightsDto',
        'auth_stack': 'CheckEmailAuthStackResults'
    }

    attribute_map = {
        'monitor': 'monitor',
        'latest_run': 'latestRun',
        'insights': 'insights',
        'auth_stack': 'authStack'
    }

    def __init__(self, monitor=None, latest_run=None, insights=None, auth_stack=None, local_vars_configuration=None):  # noqa: E501
        """DomainMonitorSummaryDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._monitor = None
        self._latest_run = None
        self._insights = None
        self._auth_stack = None
        self.discriminator = None

        self.monitor = monitor
        if latest_run is not None:
            self.latest_run = latest_run
        self.insights = insights
        self.auth_stack = auth_stack

    @property
    def monitor(self):
        """Gets the monitor of this DomainMonitorSummaryDto.  # noqa: E501


        :return: The monitor of this DomainMonitorSummaryDto.  # noqa: E501
        :rtype: DomainMonitorDto
        """
        return self._monitor

    @monitor.setter
    def monitor(self, monitor):
        """Sets the monitor of this DomainMonitorSummaryDto.


        :param monitor: The monitor of this DomainMonitorSummaryDto.  # noqa: E501
        :type: DomainMonitorDto
        """
        if self.local_vars_configuration.client_side_validation and monitor is None:  # noqa: E501
            raise ValueError("Invalid value for `monitor`, must not be `None`")  # noqa: E501

        self._monitor = monitor

    @property
    def latest_run(self):
        """Gets the latest_run of this DomainMonitorSummaryDto.  # noqa: E501


        :return: The latest_run of this DomainMonitorSummaryDto.  # noqa: E501
        :rtype: DomainMonitorRunDto
        """
        return self._latest_run

    @latest_run.setter
    def latest_run(self, latest_run):
        """Sets the latest_run of this DomainMonitorSummaryDto.


        :param latest_run: The latest_run of this DomainMonitorSummaryDto.  # noqa: E501
        :type: DomainMonitorRunDto
        """

        self._latest_run = latest_run

    @property
    def insights(self):
        """Gets the insights of this DomainMonitorSummaryDto.  # noqa: E501


        :return: The insights of this DomainMonitorSummaryDto.  # noqa: E501
        :rtype: DomainMonitorInsightsDto
        """
        return self._insights

    @insights.setter
    def insights(self, insights):
        """Sets the insights of this DomainMonitorSummaryDto.


        :param insights: The insights of this DomainMonitorSummaryDto.  # noqa: E501
        :type: DomainMonitorInsightsDto
        """
        if self.local_vars_configuration.client_side_validation and insights is None:  # noqa: E501
            raise ValueError("Invalid value for `insights`, must not be `None`")  # noqa: E501

        self._insights = insights

    @property
    def auth_stack(self):
        """Gets the auth_stack of this DomainMonitorSummaryDto.  # noqa: E501


        :return: The auth_stack of this DomainMonitorSummaryDto.  # noqa: E501
        :rtype: CheckEmailAuthStackResults
        """
        return self._auth_stack

    @auth_stack.setter
    def auth_stack(self, auth_stack):
        """Sets the auth_stack of this DomainMonitorSummaryDto.


        :param auth_stack: The auth_stack of this DomainMonitorSummaryDto.  # noqa: E501
        :type: CheckEmailAuthStackResults
        """
        if self.local_vars_configuration.client_side_validation and auth_stack is None:  # noqa: E501
            raise ValueError("Invalid value for `auth_stack`, must not be `None`")  # noqa: E501

        self._auth_stack = auth_stack

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DomainMonitorSummaryDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DomainMonitorSummaryDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CampaignProbeSeriesPointDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bucket_start': 'datetime',
        'run_count': 'int',
        'healthy_count': 'int',
        'warning_count': 'int',
        'failed_count': 'int',
        'healthy_rate': 'float',
        'average_health_score': 'float'
    }

    attribute_map = {
        'bucket_start': 'bucketStart',
        'run_count': 'runCount',
        'healthy_count': 'healthyCount',
        'warning_count': 'warningCount',
        'failed_count': 'failedCount',
        'healthy_rate': 'healthyRate',
        'average_health_score': 'averageHealthScore'
    }

    def __init__(self, bucket_start=None, run_count=None, healthy_count=None, warning_count=None, failed_count=None, healthy_rate=None, average_health_score=None, local_vars_configuration=None):  # noqa: E501
        """CampaignProbeSeriesPointDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bucket_start = None
        self._run_count = None
        self._healthy_count = None
        self._warning_count = None
        self._failed_count = None
        self._healthy_rate = None
        self._average_health_score = None
        self.discriminator = None

        self.bucket_start = bucket_start
        self.run_count = run_count
        self.healthy_count = healthy_count
        self.warning_count = warning_count
        self.failed_count = failed_count
        self.healthy_rate = healthy_rate
        self.average_health_score = average_health_score

    @property
    def bucket_start(self):
        """Gets the bucket_start of this CampaignProbeSeriesPointDto.  # noqa: E501


        :return: The bucket_start of this CampaignProbeSeriesPointDto.  # noqa: E501
        :rtype: datetime
        """
        return self._bucket_start

    @bucket_start.setter
    def bucket_start(self, bucket_start):
        """Sets the bucket_start of this CampaignProbeSeriesPointDto.


        :param bucket_start: The bucket_start of this CampaignProbeSeriesPointDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and bucket_start is None:  # noqa: E501
            raise ValueError("Invalid value for `bucket_start`, must not be `None`")  # noqa: E501

        self._bucket_start = bucket_start

    @property
    def run_count(self):
        """Gets the run_count of this CampaignProbeSeriesPointDto.  # noqa: E501


        :return: The run_count of this CampaignProbeSeriesPointDto.  # noqa: E501
        :rtype: int
        """
        return self._run_count

    @run_count.setter
    def run_count(self, run_count):
        """Sets the run_count of this CampaignProbeSeriesPointDto.


        :param run_count: The run_count of this CampaignProbeSeriesPointDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and run_count is None:  # noqa: E501
            raise ValueError("Invalid value for `run_count`, must not be `None`")  # noqa: E501

        self._run_count = run_count

    @property
    def healthy_count(self):
        """Gets the healthy_count of this CampaignProbeSeriesPointDto.  # noqa: E501


        :return: The healthy_count of this CampaignProbeSeriesPointDto.  # noqa: E501
        :rtype: int
        """
        return self._healthy_count

    @healthy_count.setter
    def healthy_count(self, healthy_count):
        """Sets the healthy_count of this CampaignProbeSeriesPointDto.


        :param healthy_count: The healthy_count of this CampaignProbeSeriesPointDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and healthy_count is None:  # noqa: E501
            raise ValueError("Invalid value for `healthy_count`, must not be `None`")  # noqa: E501

        self._healthy_count = healthy_count

    @property
    def warning_count(self):
        """Gets the warning_count of this CampaignProbeSeriesPointDto.  # noqa: E501


        :return: The warning_count of this CampaignProbeSeriesPointDto.  # noqa: E501
        :rtype: int
        """
        return self._warning_count

    @warning_count.setter
    def warning_count(self, warning_count):
        """Sets the warning_count of this CampaignProbeSeriesPointDto.


        :param warning_count: The warning_count of this CampaignProbeSeriesPointDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and warning_count is None:  # noqa: E501
            raise ValueError("Invalid value for `warning_count`, must not be `None`")  # noqa: E501

        self._warning_count = warning_count

    @property
    def failed_count(self):
        """Gets the failed_count of this CampaignProbeSeriesPointDto.  # noqa: E501


        :return: The failed_count of this CampaignProbeSeriesPointDto.  # noqa: E501
        :rtype: int
        """
        return self._failed_count

    @failed_count.setter
    def failed_count(self, failed_count):
        """Sets the failed_count of this CampaignProbeSeriesPointDto.


        :param failed_count: The failed_count of this CampaignProbeSeriesPointDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failed_count is None:  # noqa: E501
            raise ValueError("Invalid value for `failed_count`, must not be `None`")  # noqa: E501

        self._failed_count = failed_count

    @property
    def healthy_rate(self):
        """Gets the healthy_rate of this CampaignProbeSeriesPointDto.  # noqa: E501


        :return: The healthy_rate of this CampaignProbeSeriesPointDto.  # noqa: E501
        :rtype: float
        """
        return self._healthy_rate

    @healthy_rate.setter
    def healthy_rate(self, healthy_rate):
        """Sets the healthy_rate of this CampaignProbeSeriesPointDto.


        :param healthy_rate: The healthy_rate of this CampaignProbeSeriesPointDto.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and healthy_rate is None:  # noqa: E501
            raise ValueError("Invalid value for `healthy_rate`, must not be `None`")  # noqa: E501

        self._healthy_rate = healthy_rate

    @property
    def average_health_score(self):
        """Gets the average_health_score of this CampaignProbeSeriesPointDto.  # noqa: E501


        :return: The average_health_score of this CampaignProbeSeriesPointDto.  # noqa: E501
        :rtype: float
        """
        return self._average_health_score

    @average_health_score.setter
    def average_health_score(self, average_health_score):
        """Sets the average_health_score of this CampaignProbeSeriesPointDto.


        :param average_health_score: The average_health_score of this CampaignProbeSeriesPointDto.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and average_health_score is None:  # noqa: E501
            raise ValueError("Invalid value for `average_health_score`, must not be `None`")  # noqa: E501

        self._average_health_score = average_health_score

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignProbeSeriesPointDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignProbeSeriesPointDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CampaignProbeRunDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'probe_id': 'str',
        'user_id': 'str',
        'status': 'str',
        'source': 'str',
        'health_score': 'int',
        'total_checks': 'int',
        'passing_checks': 'int',
        'failing_checks': 'int',
        'checked_links': 'int',
        'checked_images': 'int',
        'link_issue_count': 'int',
        'image_issue_count': 'int',
        'compatibility_warning_count': 'int',
        'compatibility_not_supported_count': 'int',
        'compatibility_unknown_count': 'int',
        'html_error_count': 'int',
        'html_warning_count': 'int',
        'html_info_count': 'int',
        'reputation_failure_count': 'int',
        'attachment_mention_issue_count': 'int',
        'insights': 'list[str]',
        'error_message': 'str',
        'from_address': 'str',
        'recipient': 'str',
        'subject': 'str',
        'message_id': 'str',
        'source_message_id': 'str',
        'processing_ms': 'int',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'probe_id': 'probeId',
        'user_id': 'userId',
        'status': 'status',
        'source': 'source',
        'health_score': 'healthScore',
        'total_checks': 'totalChecks',
        'passing_checks': 'passingChecks',
        'failing_checks': 'failingChecks',
        'checked_links': 'checkedLinks',
        'checked_images': 'checkedImages',
        'link_issue_count': 'linkIssueCount',
        'image_issue_count': 'imageIssueCount',
        'compatibility_warning_count': 'compatibilityWarningCount',
        'compatibility_not_supported_count': 'compatibilityNotSupportedCount',
        'compatibility_unknown_count': 'compatibilityUnknownCount',
        'html_error_count': 'htmlErrorCount',
        'html_warning_count': 'htmlWarningCount',
        'html_info_count': 'htmlInfoCount',
        'reputation_failure_count': 'reputationFailureCount',
        'attachment_mention_issue_count': 'attachmentMentionIssueCount',
        'insights': 'insights',
        'error_message': 'errorMessage',
        'from_address': 'fromAddress',
        'recipient': 'recipient',
        'subject': 'subject',
        'message_id': 'messageId',
        'source_message_id': 'sourceMessageId',
        'processing_ms': 'processingMs',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, probe_id=None, user_id=None, status=None, source=None, health_score=None, total_checks=None, passing_checks=None, failing_checks=None, checked_links=None, checked_images=None, link_issue_count=None, image_issue_count=None, compatibility_warning_count=None, compatibility_not_supported_count=None, compatibility_unknown_count=None, html_error_count=None, html_warning_count=None, html_info_count=None, reputation_failure_count=None, attachment_mention_issue_count=None, insights=None, error_message=None, from_address=None, recipient=None, subject=None, message_id=None, source_message_id=None, processing_ms=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """CampaignProbeRunDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._probe_id = None
        self._user_id = None
        self._status = None
        self._source = None
        self._health_score = None
        self._total_checks = None
        self._passing_checks = None
        self._failing_checks = None
        self._checked_links = None
        self._checked_images = None
        self._link_issue_count = None
        self._image_issue_count = None
        self._compatibility_warning_count = None
        self._compatibility_not_supported_count = None
        self._compatibility_unknown_count = None
        self._html_error_count = None
        self._html_warning_count = None
        self._html_info_count = None
        self._reputation_failure_count = None
        self._attachment_mention_issue_count = None
        self._insights = None
        self._error_message = None
        self._from_address = None
        self._recipient = None
        self._subject = None
        self._message_id = None
        self._source_message_id = None
        self._processing_ms = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.probe_id = probe_id
        self.user_id = user_id
        self.status = status
        self.source = source
        self.health_score = health_score
        self.total_checks = total_checks
        self.passing_checks = passing_checks
        self.failing_checks = failing_checks
        self.checked_links = checked_links
        self.checked_images = checked_images
        self.link_issue_count = link_issue_count
        self.image_issue_count = image_issue_count
        self.compatibility_warning_count = compatibility_warning_count
        self.compatibility_not_supported_count = compatibility_not_supported_count
        self.compatibility_unknown_count = compatibility_unknown_count
        self.html_error_count = html_error_count
        self.html_warning_count = html_warning_count
        self.html_info_count = html_info_count
        self.reputation_failure_count = reputation_failure_count
        self.attachment_mention_issue_count = attachment_mention_issue_count
        self.insights = insights
        if error_message is not None:
            self.error_message = error_message
        if from_address is not None:
            self.from_address = from_address
        if recipient is not None:
            self.recipient = recipient
        if subject is not None:
            self.subject = subject
        if message_id is not None:
            self.message_id = message_id
        if source_message_id is not None:
            self.source_message_id = source_message_id
        if processing_ms is not None:
            self.processing_ms = processing_ms
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this CampaignProbeRunDto.  # noqa: E501


        :return: The id of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CampaignProbeRunDto.


        :param id: The id of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def probe_id(self):
        """Gets the probe_id of this CampaignProbeRunDto.  # noqa: E501


        :return: The probe_id of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._probe_id

    @probe_id.setter
    def probe_id(self, probe_id):
        """Sets the probe_id of this CampaignProbeRunDto.


        :param probe_id: The probe_id of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and probe_id is None:  # noqa: E501
            raise ValueError("Invalid value for `probe_id`, must not be `None`")  # noqa: E501

        self._probe_id = probe_id

    @property
    def user_id(self):
        """Gets the user_id of this CampaignProbeRunDto.  # noqa: E501


        :return: The user_id of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this CampaignProbeRunDto.


        :param user_id: The user_id of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def status(self):
        """Gets the status of this CampaignProbeRunDto.  # noqa: E501


        :return: The status of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CampaignProbeRunDto.


        :param status: The status of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["HEALTHY", "WARNING", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def source(self):
        """Gets the source of this CampaignProbeRunDto.  # noqa: E501


        :return: The source of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this CampaignProbeRunDto.


        :param source: The source of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and source is None:  # noqa: E501
            raise ValueError("Invalid value for `source`, must not be `None`")  # noqa: E501
        allowed_values = ["DIRECT_API", "SES_MONITOR", "USER_SCHEDULE", "CRON", "SCHEDULER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and source not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `source` ({0}), must be one of {1}"  # noqa: E501
                .format(source, allowed_values)
            )

        self._source = source

    @property
    def health_score(self):
        """Gets the health_score of this CampaignProbeRunDto.  # noqa: E501


        :return: The health_score of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._health_score

    @health_score.setter
    def health_score(self, health_score):
        """Sets the health_score of this CampaignProbeRunDto.


        :param health_score: The health_score of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and health_score is None:  # noqa: E501
            raise ValueError("Invalid value for `health_score`, must not be `None`")  # noqa: E501

        self._health_score = health_score

    @property
    def total_checks(self):
        """Gets the total_checks of this CampaignProbeRunDto.  # noqa: E501


        :return: The total_checks of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._total_checks

    @total_checks.setter
    def total_checks(self, total_checks):
        """Sets the total_checks of this CampaignProbeRunDto.


        :param total_checks: The total_checks of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `total_checks`, must not be `None`")  # noqa: E501

        self._total_checks = total_checks

    @property
    def passing_checks(self):
        """Gets the passing_checks of this CampaignProbeRunDto.  # noqa: E501


        :return: The passing_checks of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._passing_checks

    @passing_checks.setter
    def passing_checks(self, passing_checks):
        """Sets the passing_checks of this CampaignProbeRunDto.


        :param passing_checks: The passing_checks of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and passing_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `passing_checks`, must not be `None`")  # noqa: E501

        self._passing_checks = passing_checks

    @property
    def failing_checks(self):
        """Gets the failing_checks of this CampaignProbeRunDto.  # noqa: E501


        :return: The failing_checks of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._failing_checks

    @failing_checks.setter
    def failing_checks(self, failing_checks):
        """Sets the failing_checks of this CampaignProbeRunDto.


        :param failing_checks: The failing_checks of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failing_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `failing_checks`, must not be `None`")  # noqa: E501

        self._failing_checks = failing_checks

    @property
    def checked_links(self):
        """Gets the checked_links of this CampaignProbeRunDto.  # noqa: E501


        :return: The checked_links of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._checked_links

    @checked_links.setter
    def checked_links(self, checked_links):
        """Sets the checked_links of this CampaignProbeRunDto.


        :param checked_links: The checked_links of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and checked_links is None:  # noqa: E501
            raise ValueError("Invalid value for `checked_links`, must not be `None`")  # noqa: E501

        self._checked_links = checked_links

    @property
    def checked_images(self):
        """Gets the checked_images of this CampaignProbeRunDto.  # noqa: E501


        :return: The checked_images of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._checked_images

    @checked_images.setter
    def checked_images(self, checked_images):
        """Sets the checked_images of this CampaignProbeRunDto.


        :param checked_images: The checked_images of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and checked_images is None:  # noqa: E501
            raise ValueError("Invalid value for `checked_images`, must not be `None`")  # noqa: E501

        self._checked_images = checked_images

    @property
    def link_issue_count(self):
        """Gets the link_issue_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The link_issue_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._link_issue_count

    @link_issue_count.setter
    def link_issue_count(self, link_issue_count):
        """Sets the link_issue_count of this CampaignProbeRunDto.


        :param link_issue_count: The link_issue_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and link_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `link_issue_count`, must not be `None`")  # noqa: E501

        self._link_issue_count = link_issue_count

    @property
    def image_issue_count(self):
        """Gets the image_issue_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The image_issue_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._image_issue_count

    @image_issue_count.setter
    def image_issue_count(self, image_issue_count):
        """Sets the image_issue_count of this CampaignProbeRunDto.


        :param image_issue_count: The image_issue_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and image_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `image_issue_count`, must not be `None`")  # noqa: E501

        self._image_issue_count = image_issue_count

    @property
    def compatibility_warning_count(self):
        """Gets the compatibility_warning_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The compatibility_warning_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_warning_count

    @compatibility_warning_count.setter
    def compatibility_warning_count(self, compatibility_warning_count):
        """Sets the compatibility_warning_count of this CampaignProbeRunDto.


        :param compatibility_warning_count: The compatibility_warning_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_warning_count is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_warning_count`, must not be `None`")  # noqa: E501

        self._compatibility_warning_count = compatibility_warning_count

    @property
    def compatibility_not_supported_count(self):
        """Gets the compatibility_not_supported_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The compatibility_not_supported_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_not_supported_count

    @compatibility_not_supported_count.setter
    def compatibility_not_supported_count(self, compatibility_not_supported_count):
        """Sets the compatibility_not_supported_count of this CampaignProbeRunDto.


        :param compatibility_not_supported_count: The compatibility_not_supported_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_not_supported_count is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_not_supported_count`, must not be `None`")  # noqa: E501

        self._compatibility_not_supported_count = compatibility_not_supported_count

    @property
    def compatibility_unknown_count(self):
        """Gets the compatibility_unknown_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The compatibility_unknown_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_unknown_count

    @compatibility_unknown_count.setter
    def compatibility_unknown_count(self, compatibility_unknown_count):
        """Sets the compatibility_unknown_count of this CampaignProbeRunDto.


        :param compatibility_unknown_count: The compatibility_unknown_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_unknown_count is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_unknown_count`, must not be `None`")  # noqa: E501

        self._compatibility_unknown_count = compatibility_unknown_count

    @property
    def html_error_count(self):
        """Gets the html_error_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The html_error_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._html_error_count

    @html_error_count.setter
    def html_error_count(self, html_error_count):
        """Sets the html_error_count of this CampaignProbeRunDto.


        :param html_error_count: The html_error_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_error_count is None:  # noqa: E501
            raise ValueError("Invalid value for `html_error_count`, must not be `None`")  # noqa: E501

        self._html_error_count = html_error_count

    @property
    def html_warning_count(self):
        """Gets the html_warning_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The html_warning_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._html_warning_count

    @html_warning_count.setter
    def html_warning_count(self, html_warning_count):
        """Sets the html_warning_count of this CampaignProbeRunDto.


        :param html_warning_count: The html_warning_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_warning_count is None:  # noqa: E501
            raise ValueError("Invalid value for `html_warning_count`, must not be `None`")  # noqa: E501

        self._html_warning_count = html_warning_count

    @property
    def html_info_count(self):
        """Gets the html_info_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The html_info_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._html_info_count

    @html_info_count.setter
    def html_info_count(self, html_info_count):
        """Sets the html_info_count of this CampaignProbeRunDto.


        :param html_info_count: The html_info_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_info_count is None:  # noqa: E501
            raise ValueError("Invalid value for `html_info_count`, must not be `None`")  # noqa: E501

        self._html_info_count = html_info_count

    @property
    def reputation_failure_count(self):
        """Gets the reputation_failure_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The reputation_failure_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._reputation_failure_count

    @reputation_failure_count.setter
    def reputation_failure_count(self, reputation_failure_count):
        """Sets the reputation_failure_count of this CampaignProbeRunDto.


        :param reputation_failure_count: The reputation_failure_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and reputation_failure_count is None:  # noqa: E501
            raise ValueError("Invalid value for `reputation_failure_count`, must not be `None`")  # noqa: E501

        self._reputation_failure_count = reputation_failure_count

    @property
    def attachment_mention_issue_count(self):
        """Gets the attachment_mention_issue_count of this CampaignProbeRunDto.  # noqa: E501


        :return: The attachment_mention_issue_count of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._attachment_mention_issue_count

    @attachment_mention_issue_count.setter
    def attachment_mention_issue_count(self, attachment_mention_issue_count):
        """Sets the attachment_mention_issue_count of this CampaignProbeRunDto.


        :param attachment_mention_issue_count: The attachment_mention_issue_count of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and attachment_mention_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `attachment_mention_issue_count`, must not be `None`")  # noqa: E501

        self._attachment_mention_issue_count = attachment_mention_issue_count

    @property
    def insights(self):
        """Gets the insights of this CampaignProbeRunDto.  # noqa: E501


        :return: The insights of this CampaignProbeRunDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._insights

    @insights.setter
    def insights(self, insights):
        """Sets the insights of this CampaignProbeRunDto.


        :param insights: The insights of this CampaignProbeRunDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and insights is None:  # noqa: E501
            raise ValueError("Invalid value for `insights`, must not be `None`")  # noqa: E501

        self._insights = insights

    @property
    def error_message(self):
        """Gets the error_message of this CampaignProbeRunDto.  # noqa: E501


        :return: The error_message of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this CampaignProbeRunDto.


        :param error_message: The error_message of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def from_address(self):
        """Gets the from_address of this CampaignProbeRunDto.  # noqa: E501


        :return: The from_address of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._from_address

    @from_address.setter
    def from_address(self, from_address):
        """Sets the from_address of this CampaignProbeRunDto.


        :param from_address: The from_address of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """

        self._from_address = from_address

    @property
    def recipient(self):
        """Gets the recipient of this CampaignProbeRunDto.  # noqa: E501


        :return: The recipient of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._recipient

    @recipient.setter
    def recipient(self, recipient):
        """Sets the recipient of this CampaignProbeRunDto.


        :param recipient: The recipient of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """

        self._recipient = recipient

    @property
    def subject(self):
        """Gets the subject of this CampaignProbeRunDto.  # noqa: E501


        :return: The subject of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this CampaignProbeRunDto.


        :param subject: The subject of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def message_id(self):
        """Gets the message_id of this CampaignProbeRunDto.  # noqa: E501


        :return: The message_id of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """Sets the message_id of this CampaignProbeRunDto.


        :param message_id: The message_id of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """

        self._message_id = message_id

    @property
    def source_message_id(self):
        """Gets the source_message_id of this CampaignProbeRunDto.  # noqa: E501


        :return: The source_message_id of this CampaignProbeRunDto.  # noqa: E501
        :rtype: str
        """
        return self._source_message_id

    @source_message_id.setter
    def source_message_id(self, source_message_id):
        """Sets the source_message_id of this CampaignProbeRunDto.


        :param source_message_id: The source_message_id of this CampaignProbeRunDto.  # noqa: E501
        :type: str
        """

        self._source_message_id = source_message_id

    @property
    def processing_ms(self):
        """Gets the processing_ms of this CampaignProbeRunDto.  # noqa: E501


        :return: The processing_ms of this CampaignProbeRunDto.  # noqa: E501
        :rtype: int
        """
        return self._processing_ms

    @processing_ms.setter
    def processing_ms(self, processing_ms):
        """Sets the processing_ms of this CampaignProbeRunDto.


        :param processing_ms: The processing_ms of this CampaignProbeRunDto.  # noqa: E501
        :type: int
        """

        self._processing_ms = processing_ms

    @property
    def created_at(self):
        """Gets the created_at of this CampaignProbeRunDto.  # noqa: E501


        :return: The created_at of this CampaignProbeRunDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this CampaignProbeRunDto.


        :param created_at: The created_at of this CampaignProbeRunDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this CampaignProbeRunDto.  # noqa: E501


        :return: The updated_at of this CampaignProbeRunDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this CampaignProbeRunDto.


        :param updated_at: The updated_at of this CampaignProbeRunDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignProbeRunDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignProbeRunDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CreateDeliverabilityTestOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'description': 'str',
        'scope': 'str',
        'start_at': 'datetime',
        'max_duration_seconds': 'int',
        'success_threshold_percent': 'float',
        'selector': 'DeliverabilitySelectorOptions',
        'expectations': 'list[DeliverabilityExpectation]'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'scope': 'scope',
        'start_at': 'startAt',
        'max_duration_seconds': 'maxDurationSeconds',
        'success_threshold_percent': 'successThresholdPercent',
        'selector': 'selector',
        'expectations': 'expectations'
    }

    def __init__(self, name=None, description=None, scope=None, start_at=None, max_duration_seconds=None, success_threshold_percent=None, selector=None, expectations=None, local_vars_configuration=None):  # noqa: E501
        """CreateDeliverabilityTestOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._description = None
        self._scope = None
        self._start_at = None
        self._max_duration_seconds = None
        self._success_threshold_percent = None
        self._selector = None
        self._expectations = None
        self.discriminator = None

        self.name = name
        self.description = description
        self.scope = scope
        self.start_at = start_at
        self.max_duration_seconds = max_duration_seconds
        self.success_threshold_percent = success_threshold_percent
        self.selector = selector
        self.expectations = expectations

    @property
    def name(self):
        """Gets the name of this CreateDeliverabilityTestOptions.  # noqa: E501

        Optional name for the test  # noqa: E501

        :return: The name of this CreateDeliverabilityTestOptions.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateDeliverabilityTestOptions.

        Optional name for the test  # noqa: E501

        :param name: The name of this CreateDeliverabilityTestOptions.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this CreateDeliverabilityTestOptions.  # noqa: E501

        Optional description  # noqa: E501

        :return: The description of this CreateDeliverabilityTestOptions.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateDeliverabilityTestOptions.

        Optional description  # noqa: E501

        :param description: The description of this CreateDeliverabilityTestOptions.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def scope(self):
        """Gets the scope of this CreateDeliverabilityTestOptions.  # noqa: E501

        Entity scope to evaluate  # noqa: E501

        :return: The scope of this CreateDeliverabilityTestOptions.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this CreateDeliverabilityTestOptions.

        Entity scope to evaluate  # noqa: E501

        :param scope: The scope of this CreateDeliverabilityTestOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and scope is None:  # noqa: E501
            raise ValueError("Invalid value for `scope`, must not be `None`")  # noqa: E501
        allowed_values = ["INBOX", "PHONE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and scope not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `scope` ({0}), must be one of {1}"  # noqa: E501
                .format(scope, allowed_values)
            )

        self._scope = scope

    @property
    def start_at(self):
        """Gets the start_at of this CreateDeliverabilityTestOptions.  # noqa: E501

        UTC instant when the receive window starts. Defaults to now if omitted.  # noqa: E501

        :return: The start_at of this CreateDeliverabilityTestOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._start_at

    @start_at.setter
    def start_at(self, start_at):
        """Sets the start_at of this CreateDeliverabilityTestOptions.

        UTC instant when the receive window starts. Defaults to now if omitted.  # noqa: E501

        :param start_at: The start_at of this CreateDeliverabilityTestOptions.  # noqa: E501
        :type: datetime
        """

        self._start_at = start_at

    @property
    def max_duration_seconds(self):
        """Gets the max_duration_seconds of this CreateDeliverabilityTestOptions.  # noqa: E501

        Optional timeout in seconds after startAt. If not all entities match before timeout the test transitions to FAILED.  # noqa: E501

        :return: The max_duration_seconds of this CreateDeliverabilityTestOptions.  # noqa: E501
        :rtype: int
        """
        return self._max_duration_seconds

    @max_duration_seconds.setter
    def max_duration_seconds(self, max_duration_seconds):
        """Sets the max_duration_seconds of this CreateDeliverabilityTestOptions.

        Optional timeout in seconds after startAt. If not all entities match before timeout the test transitions to FAILED.  # noqa: E501

        :param max_duration_seconds: The max_duration_seconds of this CreateDeliverabilityTestOptions.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                max_duration_seconds is not None and max_duration_seconds < 1):  # noqa: E501
            raise ValueError("Invalid value for `max_duration_seconds`, must be a value greater than or equal to `1`")  # noqa: E501

        self._max_duration_seconds = max_duration_seconds

    @property
    def success_threshold_percent(self):
        """Gets the success_threshold_percent of this CreateDeliverabilityTestOptions.  # noqa: E501

        Optional acceptable success threshold percentage (0,100]. If set, a timed-out test can complete successfully when matchedEntities/totalEntities reaches this percentage.  # noqa: E501

        :return: The success_threshold_percent of this CreateDeliverabilityTestOptions.  # noqa: E501
        :rtype: float
        """
        return self._success_threshold_percent

    @success_threshold_percent.setter
    def success_threshold_percent(self, success_threshold_percent):
        """Sets the success_threshold_percent of this CreateDeliverabilityTestOptions.

        Optional acceptable success threshold percentage (0,100]. If set, a timed-out test can complete successfully when matchedEntities/totalEntities reaches this percentage.  # noqa: E501

        :param success_threshold_percent: The success_threshold_percent of this CreateDeliverabilityTestOptions.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                success_threshold_percent is not None and success_threshold_percent > 100.0):  # noqa: E501
            raise ValueError("Invalid value for `success_threshold_percent`, must be a value less than or equal to `100.0`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                success_threshold_percent is not None and success_threshold_percent <= 0.0):  # noqa: E501
            raise ValueError("Invalid value for `success_threshold_percent`, must be a value greater than `0.0`")  # noqa: E501

        self._success_threshold_percent = success_threshold_percent

    @property
    def selector(self):
        """Gets the selector of this CreateDeliverabilityTestOptions.  # noqa: E501


        :return: The selector of this CreateDeliverabilityTestOptions.  # noqa: E501
        :rtype: DeliverabilitySelectorOptions
        """
        return self._selector

    @selector.setter
    def selector(self, selector):
        """Sets the selector of this CreateDeliverabilityTestOptions.


        :param selector: The selector of this CreateDeliverabilityTestOptions.  # noqa: E501
        :type: DeliverabilitySelectorOptions
        """
        if self.local_vars_configuration.client_side_validation and selector is None:  # noqa: E501
            raise ValueError("Invalid value for `selector`, must not be `None`")  # noqa: E501

        self._selector = selector

    @property
    def expectations(self):
        """Gets the expectations of this CreateDeliverabilityTestOptions.  # noqa: E501

        One or more expectations to evaluate for each entity  # noqa: E501

        :return: The expectations of this CreateDeliverabilityTestOptions.  # noqa: E501
        :rtype: list[DeliverabilityExpectation]
        """
        return self._expectations

    @expectations.setter
    def expectations(self, expectations):
        """Sets the expectations of this CreateDeliverabilityTestOptions.

        One or more expectations to evaluate for each entity  # noqa: E501

        :param expectations: The expectations of this CreateDeliverabilityTestOptions.  # noqa: E501
        :type: list[DeliverabilityExpectation]
        """
        if self.local_vars_configuration.client_side_validation and expectations is None:  # noqa: E501
            raise ValueError("Invalid value for `expectations`, must not be `None`")  # noqa: E501

        self._expectations = expectations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateDeliverabilityTestOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateDeliverabilityTestOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CheckEmailAuthStackResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'domain': 'str',
        'status': 'str',
        'health_score': 'int',
        'total_checks': 'int',
        'passing_checks': 'int',
        'failing_checks': 'int',
        'spf': 'LookupSpfDomainResults',
        'dmarc': 'LookupDmarcDomainResults',
        'dkim': 'LookupDkimDomainResults',
        'bimi': 'LookupBimiDomainResults',
        'mx': 'LookupMxRecordsResults',
        'mta_sts': 'LookupMtaStsDomainResults',
        'tls_reporting': 'LookupTlsReportingDomainResults',
        'insights': 'list[str]',
        'warnings': 'list[str]',
        'errors': 'list[str]'
    }

    attribute_map = {
        'domain': 'domain',
        'status': 'status',
        'health_score': 'healthScore',
        'total_checks': 'totalChecks',
        'passing_checks': 'passingChecks',
        'failing_checks': 'failingChecks',
        'spf': 'spf',
        'dmarc': 'dmarc',
        'dkim': 'dkim',
        'bimi': 'bimi',
        'mx': 'mx',
        'mta_sts': 'mtaSts',
        'tls_reporting': 'tlsReporting',
        'insights': 'insights',
        'warnings': 'warnings',
        'errors': 'errors'
    }

    def __init__(self, domain=None, status=None, health_score=None, total_checks=None, passing_checks=None, failing_checks=None, spf=None, dmarc=None, dkim=None, bimi=None, mx=None, mta_sts=None, tls_reporting=None, insights=None, warnings=None, errors=None, local_vars_configuration=None):  # noqa: E501
        """CheckEmailAuthStackResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._domain = None
        self._status = None
        self._health_score = None
        self._total_checks = None
        self._passing_checks = None
        self._failing_checks = None
        self._spf = None
        self._dmarc = None
        self._dkim = None
        self._bimi = None
        self._mx = None
        self._mta_sts = None
        self._tls_reporting = None
        self._insights = None
        self._warnings = None
        self._errors = None
        self.discriminator = None

        self.domain = domain
        self.status = status
        self.health_score = health_score
        self.total_checks = total_checks
        self.passing_checks = passing_checks
        self.failing_checks = failing_checks
        self.spf = spf
        self.dmarc = dmarc
        self.dkim = dkim
        self.bimi = bimi
        self.mx = mx
        self.mta_sts = mta_sts
        self.tls_reporting = tls_reporting
        self.insights = insights
        self.warnings = warnings
        self.errors = errors

    @property
    def domain(self):
        """Gets the domain of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The domain of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this CheckEmailAuthStackResults.


        :param domain: The domain of this CheckEmailAuthStackResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and domain is None:  # noqa: E501
            raise ValueError("Invalid value for `domain`, must not be `None`")  # noqa: E501

        self._domain = domain

    @property
    def status(self):
        """Gets the status of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The status of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CheckEmailAuthStackResults.


        :param status: The status of this CheckEmailAuthStackResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["HEALTHY", "DEGRADED", "CRITICAL", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def health_score(self):
        """Gets the health_score of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The health_score of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: int
        """
        return self._health_score

    @health_score.setter
    def health_score(self, health_score):
        """Sets the health_score of this CheckEmailAuthStackResults.


        :param health_score: The health_score of this CheckEmailAuthStackResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and health_score is None:  # noqa: E501
            raise ValueError("Invalid value for `health_score`, must not be `None`")  # noqa: E501

        self._health_score = health_score

    @property
    def total_checks(self):
        """Gets the total_checks of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The total_checks of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: int
        """
        return self._total_checks

    @total_checks.setter
    def total_checks(self, total_checks):
        """Sets the total_checks of this CheckEmailAuthStackResults.


        :param total_checks: The total_checks of this CheckEmailAuthStackResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `total_checks`, must not be `None`")  # noqa: E501

        self._total_checks = total_checks

    @property
    def passing_checks(self):
        """Gets the passing_checks of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The passing_checks of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: int
        """
        return self._passing_checks

    @passing_checks.setter
    def passing_checks(self, passing_checks):
        """Sets the passing_checks of this CheckEmailAuthStackResults.


        :param passing_checks: The passing_checks of this CheckEmailAuthStackResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and passing_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `passing_checks`, must not be `None`")  # noqa: E501

        self._passing_checks = passing_checks

    @property
    def failing_checks(self):
        """Gets the failing_checks of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The failing_checks of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: int
        """
        return self._failing_checks

    @failing_checks.setter
    def failing_checks(self, failing_checks):
        """Sets the failing_checks of this CheckEmailAuthStackResults.


        :param failing_checks: The failing_checks of this CheckEmailAuthStackResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failing_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `failing_checks`, must not be `None`")  # noqa: E501

        self._failing_checks = failing_checks

    @property
    def spf(self):
        """Gets the spf of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The spf of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: LookupSpfDomainResults
        """
        return self._spf

    @spf.setter
    def spf(self, spf):
        """Sets the spf of this CheckEmailAuthStackResults.


        :param spf: The spf of this CheckEmailAuthStackResults.  # noqa: E501
        :type: LookupSpfDomainResults
        """
        if self.local_vars_configuration.client_side_validation and spf is None:  # noqa: E501
            raise ValueError("Invalid value for `spf`, must not be `None`")  # noqa: E501

        self._spf = spf

    @property
    def dmarc(self):
        """Gets the dmarc of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The dmarc of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: LookupDmarcDomainResults
        """
        return self._dmarc

    @dmarc.setter
    def dmarc(self, dmarc):
        """Sets the dmarc of this CheckEmailAuthStackResults.


        :param dmarc: The dmarc of this CheckEmailAuthStackResults.  # noqa: E501
        :type: LookupDmarcDomainResults
        """
        if self.local_vars_configuration.client_side_validation and dmarc is None:  # noqa: E501
            raise ValueError("Invalid value for `dmarc`, must not be `None`")  # noqa: E501

        self._dmarc = dmarc

    @property
    def dkim(self):
        """Gets the dkim of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The dkim of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: LookupDkimDomainResults
        """
        return self._dkim

    @dkim.setter
    def dkim(self, dkim):
        """Sets the dkim of this CheckEmailAuthStackResults.


        :param dkim: The dkim of this CheckEmailAuthStackResults.  # noqa: E501
        :type: LookupDkimDomainResults
        """
        if self.local_vars_configuration.client_side_validation and dkim is None:  # noqa: E501
            raise ValueError("Invalid value for `dkim`, must not be `None`")  # noqa: E501

        self._dkim = dkim

    @property
    def bimi(self):
        """Gets the bimi of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The bimi of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: LookupBimiDomainResults
        """
        return self._bimi

    @bimi.setter
    def bimi(self, bimi):
        """Sets the bimi of this CheckEmailAuthStackResults.


        :param bimi: The bimi of this CheckEmailAuthStackResults.  # noqa: E501
        :type: LookupBimiDomainResults
        """
        if self.local_vars_configuration.client_side_validation and bimi is None:  # noqa: E501
            raise ValueError("Invalid value for `bimi`, must not be `None`")  # noqa: E501

        self._bimi = bimi

    @property
    def mx(self):
        """Gets the mx of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The mx of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: LookupMxRecordsResults
        """
        return self._mx

    @mx.setter
    def mx(self, mx):
        """Sets the mx of this CheckEmailAuthStackResults.


        :param mx: The mx of this CheckEmailAuthStackResults.  # noqa: E501
        :type: LookupMxRecordsResults
        """
        if self.local_vars_configuration.client_side_validation and mx is None:  # noqa: E501
            raise ValueError("Invalid value for `mx`, must not be `None`")  # noqa: E501

        self._mx = mx

    @property
    def mta_sts(self):
        """Gets the mta_sts of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The mta_sts of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: LookupMtaStsDomainResults
        """
        return self._mta_sts

    @mta_sts.setter
    def mta_sts(self, mta_sts):
        """Sets the mta_sts of this CheckEmailAuthStackResults.


        :param mta_sts: The mta_sts of this CheckEmailAuthStackResults.  # noqa: E501
        :type: LookupMtaStsDomainResults
        """
        if self.local_vars_configuration.client_side_validation and mta_sts is None:  # noqa: E501
            raise ValueError("Invalid value for `mta_sts`, must not be `None`")  # noqa: E501

        self._mta_sts = mta_sts

    @property
    def tls_reporting(self):
        """Gets the tls_reporting of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The tls_reporting of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: LookupTlsReportingDomainResults
        """
        return self._tls_reporting

    @tls_reporting.setter
    def tls_reporting(self, tls_reporting):
        """Sets the tls_reporting of this CheckEmailAuthStackResults.


        :param tls_reporting: The tls_reporting of this CheckEmailAuthStackResults.  # noqa: E501
        :type: LookupTlsReportingDomainResults
        """
        if self.local_vars_configuration.client_side_validation and tls_reporting is None:  # noqa: E501
            raise ValueError("Invalid value for `tls_reporting`, must not be `None`")  # noqa: E501

        self._tls_reporting = tls_reporting

    @property
    def insights(self):
        """Gets the insights of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The insights of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._insights

    @insights.setter
    def insights(self, insights):
        """Sets the insights of this CheckEmailAuthStackResults.


        :param insights: The insights of this CheckEmailAuthStackResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and insights is None:  # noqa: E501
            raise ValueError("Invalid value for `insights`, must not be `None`")  # noqa: E501

        self._insights = insights

    @property
    def warnings(self):
        """Gets the warnings of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The warnings of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this CheckEmailAuthStackResults.


        :param warnings: The warnings of this CheckEmailAuthStackResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    @property
    def errors(self):
        """Gets the errors of this CheckEmailAuthStackResults.  # noqa: E501


        :return: The errors of this CheckEmailAuthStackResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this CheckEmailAuthStackResults.


        :param errors: The errors of this CheckEmailAuthStackResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and errors is None:  # noqa: E501
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckEmailAuthStackResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CheckEmailAuthStackResults):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ExtractCodesResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'found': 'bool',
        'code': 'str',
        'method_used': 'str',
        'candidates': 'list[CodeCandidate]',
        'warnings': 'list[str]'
    }

    attribute_map = {
        'found': 'found',
        'code': 'code',
        'method_used': 'methodUsed',
        'candidates': 'candidates',
        'warnings': 'warnings'
    }

    def __init__(self, found=None, code=None, method_used=None, candidates=None, warnings=None, local_vars_configuration=None):  # noqa: E501
        """ExtractCodesResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._found = None
        self._code = None
        self._method_used = None
        self._candidates = None
        self._warnings = None
        self.discriminator = None

        self.found = found
        self.code = code
        self.method_used = method_used
        self.candidates = candidates
        self.warnings = warnings

    @property
    def found(self):
        """Gets the found of this ExtractCodesResult.  # noqa: E501

        True if at least one code candidate was found  # noqa: E501

        :return: The found of this ExtractCodesResult.  # noqa: E501
        :rtype: bool
        """
        return self._found

    @found.setter
    def found(self, found):
        """Sets the found of this ExtractCodesResult.

        True if at least one code candidate was found  # noqa: E501

        :param found: The found of this ExtractCodesResult.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and found is None:  # noqa: E501
            raise ValueError("Invalid value for `found`, must not be `None`")  # noqa: E501

        self._found = found

    @property
    def code(self):
        """Gets the code of this ExtractCodesResult.  # noqa: E501

        Best candidate code when found  # noqa: E501

        :return: The code of this ExtractCodesResult.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this ExtractCodesResult.

        Best candidate code when found  # noqa: E501

        :param code: The code of this ExtractCodesResult.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def method_used(self):
        """Gets the method_used of this ExtractCodesResult.  # noqa: E501

        Extraction strategy for verification codes. Unsupported strategies may fall back when allowFallback is true.  # noqa: E501

        :return: The method_used of this ExtractCodesResult.  # noqa: E501
        :rtype: str
        """
        return self._method_used

    @method_used.setter
    def method_used(self, method_used):
        """Sets the method_used of this ExtractCodesResult.

        Extraction strategy for verification codes. Unsupported strategies may fall back when allowFallback is true.  # noqa: E501

        :param method_used: The method_used of this ExtractCodesResult.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"AUTO", "PATTERN", "LLM", "OCR", "OCR_THEN_LLM"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and method_used not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `method_used` ({0}), must be one of {1}"  # noqa: E501
                .format(method_used, allowed_values)
            )

        self._method_used = method_used

    @property
    def candidates(self):
        """Gets the candidates of this ExtractCodesResult.  # noqa: E501

        Ranked code candidates  # noqa: E501

        :return: The candidates of this ExtractCodesResult.  # noqa: E501
        :rtype: list[CodeCandidate]
        """
        return self._candidates

    @candidates.setter
    def candidates(self, candidates):
        """Sets the candidates of this ExtractCodesResult.

        Ranked code candidates  # noqa: E501

        :param candidates: The candidates of this ExtractCodesResult.  # noqa: E501
        :type: list[CodeCandidate]
        """
        if self.local_vars_configuration.client_side_validation and candidates is None:  # noqa: E501
            raise ValueError("Invalid value for `candidates`, must not be `None`")  # noqa: E501

        self._candidates = candidates

    @property
    def warnings(self):
        """Gets the warnings of this ExtractCodesResult.  # noqa: E501

        Warnings or fallback notes explaining extraction behavior for debugging and QA.  # noqa: E501

        :return: The warnings of this ExtractCodesResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this ExtractCodesResult.

        Warnings or fallback notes explaining extraction behavior for debugging and QA.  # noqa: E501

        :param warnings: The warnings of this ExtractCodesResult.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExtractCodesResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExtractCodesResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PlusAddressProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'inbox_id': 'str',
        'updated_at': 'datetime',
        'created_at': 'datetime',
        'plus_address': 'str',
        'full_address': 'str'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'inbox_id': 'inboxId',
        'updated_at': 'updatedAt',
        'created_at': 'createdAt',
        'plus_address': 'plusAddress',
        'full_address': 'fullAddress'
    }

    def __init__(self, id=None, user_id=None, inbox_id=None, updated_at=None, created_at=None, plus_address=None, full_address=None, local_vars_configuration=None):  # noqa: E501
        """PlusAddressProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._inbox_id = None
        self._updated_at = None
        self._created_at = None
        self._plus_address = None
        self._full_address = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.inbox_id = inbox_id
        self.updated_at = updated_at
        self.created_at = created_at
        self.plus_address = plus_address
        self.full_address = full_address

    @property
    def id(self):
        """Gets the id of this PlusAddressProjection.  # noqa: E501


        :return: The id of this PlusAddressProjection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PlusAddressProjection.


        :param id: The id of this PlusAddressProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this PlusAddressProjection.  # noqa: E501


        :return: The user_id of this PlusAddressProjection.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this PlusAddressProjection.


        :param user_id: The user_id of this PlusAddressProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def inbox_id(self):
        """Gets the inbox_id of this PlusAddressProjection.  # noqa: E501


        :return: The inbox_id of this PlusAddressProjection.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this PlusAddressProjection.


        :param inbox_id: The inbox_id of this PlusAddressProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and inbox_id is None:  # noqa: E501
            raise ValueError("Invalid value for `inbox_id`, must not be `None`")  # noqa: E501

        self._inbox_id = inbox_id

    @property
    def updated_at(self):
        """Gets the updated_at of this PlusAddressProjection.  # noqa: E501


        :return: The updated_at of this PlusAddressProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this PlusAddressProjection.


        :param updated_at: The updated_at of this PlusAddressProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def created_at(self):
        """Gets the created_at of this PlusAddressProjection.  # noqa: E501


        :return: The created_at of this PlusAddressProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PlusAddressProjection.


        :param created_at: The created_at of this PlusAddressProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def plus_address(self):
        """Gets the plus_address of this PlusAddressProjection.  # noqa: E501


        :return: The plus_address of this PlusAddressProjection.  # noqa: E501
        :rtype: str
        """
        return self._plus_address

    @plus_address.setter
    def plus_address(self, plus_address):
        """Sets the plus_address of this PlusAddressProjection.


        :param plus_address: The plus_address of this PlusAddressProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and plus_address is None:  # noqa: E501
            raise ValueError("Invalid value for `plus_address`, must not be `None`")  # noqa: E501

        self._plus_address = plus_address

    @property
    def full_address(self):
        """Gets the full_address of this PlusAddressProjection.  # noqa: E501


        :return: The full_address of this PlusAddressProjection.  # noqa: E501
        :rtype: str
        """
        return self._full_address

    @full_address.setter
    def full_address(self, full_address):
        """Sets the full_address of this PlusAddressProjection.


        :param full_address: The full_address of this PlusAddressProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and full_address is None:  # noqa: E501
            raise ValueError("Invalid value for `full_address`, must not be `None`")  # noqa: E501

        self._full_address = full_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlusAddressProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PlusAddressProjection):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilityExpectationResultDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'expectation_index': 'int',
        'expectation_name': 'str',
        'min_count': 'int',
        'actual_count': 'int',
        'passed': 'bool',
        '_from': 'str',
        'to': 'str',
        'subject': 'str'
    }

    attribute_map = {
        'expectation_index': 'expectationIndex',
        'expectation_name': 'expectationName',
        'min_count': 'minCount',
        'actual_count': 'actualCount',
        'passed': 'passed',
        '_from': 'from',
        'to': 'to',
        'subject': 'subject'
    }

    def __init__(self, expectation_index=None, expectation_name=None, min_count=None, actual_count=None, passed=None, _from=None, to=None, subject=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilityExpectationResultDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._expectation_index = None
        self._expectation_name = None
        self._min_count = None
        self._actual_count = None
        self._passed = None
        self.__from = None
        self._to = None
        self._subject = None
        self.discriminator = None

        self.expectation_index = expectation_index
        self.expectation_name = expectation_name
        self.min_count = min_count
        self.actual_count = actual_count
        self.passed = passed
        self._from = _from
        self.to = to
        self.subject = subject

    @property
    def expectation_index(self):
        """Gets the expectation_index of this DeliverabilityExpectationResultDto.  # noqa: E501


        :return: The expectation_index of this DeliverabilityExpectationResultDto.  # noqa: E501
        :rtype: int
        """
        return self._expectation_index

    @expectation_index.setter
    def expectation_index(self, expectation_index):
        """Sets the expectation_index of this DeliverabilityExpectationResultDto.


        :param expectation_index: The expectation_index of this DeliverabilityExpectationResultDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and expectation_index is None:  # noqa: E501
            raise ValueError("Invalid value for `expectation_index`, must not be `None`")  # noqa: E501

        self._expectation_index = expectation_index

    @property
    def expectation_name(self):
        """Gets the expectation_name of this DeliverabilityExpectationResultDto.  # noqa: E501


        :return: The expectation_name of this DeliverabilityExpectationResultDto.  # noqa: E501
        :rtype: str
        """
        return self._expectation_name

    @expectation_name.setter
    def expectation_name(self, expectation_name):
        """Sets the expectation_name of this DeliverabilityExpectationResultDto.


        :param expectation_name: The expectation_name of this DeliverabilityExpectationResultDto.  # noqa: E501
        :type: str
        """

        self._expectation_name = expectation_name

    @property
    def min_count(self):
        """Gets the min_count of this DeliverabilityExpectationResultDto.  # noqa: E501


        :return: The min_count of this DeliverabilityExpectationResultDto.  # noqa: E501
        :rtype: int
        """
        return self._min_count

    @min_count.setter
    def min_count(self, min_count):
        """Sets the min_count of this DeliverabilityExpectationResultDto.


        :param min_count: The min_count of this DeliverabilityExpectationResultDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and min_count is None:  # noqa: E501
            raise ValueError("Invalid value for `min_count`, must not be `None`")  # noqa: E501

        self._min_count = min_count

    @property
    def actual_count(self):
        """Gets the actual_count of this DeliverabilityExpectationResultDto.  # noqa: E501


        :return: The actual_count of this DeliverabilityExpectationResultDto.  # noqa: E501
        :rtype: int
        """
        return self._actual_count

    @actual_count.setter
    def actual_count(self, actual_count):
        """Sets the actual_count of this DeliverabilityExpectationResultDto.


        :param actual_count: The actual_count of this DeliverabilityExpectationResultDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and actual_count is None:  # noqa: E501
            raise ValueError("Invalid value for `actual_count`, must not be `None`")  # noqa: E501

        self._actual_count = actual_count

    @property
    def passed(self):
        """Gets the passed of this DeliverabilityExpectationResultDto.  # noqa: E501


        :return: The passed of this DeliverabilityExpectationResultDto.  # noqa: E501
        :rtype: bool
        """
        return self._passed

    @passed.setter
    def passed(self, passed):
        """Sets the passed of this DeliverabilityExpectationResultDto.


        :param passed: The passed of this DeliverabilityExpectationResultDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and passed is None:  # noqa: E501
            raise ValueError("Invalid value for `passed`, must not be `None`")  # noqa: E501

        self._passed = passed

    @property
    def _from(self):
        """Gets the _from of this DeliverabilityExpectationResultDto.  # noqa: E501


        :return: The _from of this DeliverabilityExpectationResultDto.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this DeliverabilityExpectationResultDto.


        :param _from: The _from of this DeliverabilityExpectationResultDto.  # noqa: E501
        :type: str
        """

        self.__from = _from

    @property
    def to(self):
        """Gets the to of this DeliverabilityExpectationResultDto.  # noqa: E501


        :return: The to of this DeliverabilityExpectationResultDto.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this DeliverabilityExpectationResultDto.


        :param to: The to of this DeliverabilityExpectationResultDto.  # noqa: E501
        :type: str
        """

        self._to = to

    @property
    def subject(self):
        """Gets the subject of this DeliverabilityExpectationResultDto.  # noqa: E501


        :return: The subject of this DeliverabilityExpectationResultDto.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this DeliverabilityExpectationResultDto.


        :param subject: The subject of this DeliverabilityExpectationResultDto.  # noqa: E501
        :type: str
        """

        self._subject = subject

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilityExpectationResultDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilityExpectationResultDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class WebhookNewAITransformResultPayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'message_id': 'str',
        'webhook_id': 'str',
        'event_name': 'str',
        'webhook_name': 'str',
        'ai_transform_result_id': 'str',
        'user_id': 'str',
        'ai_transform_id': 'str',
        'ai_transform_mapping_id': 'str',
        'entity_id': 'str',
        'entity_type': 'str',
        'result': 'str'
    }

    attribute_map = {
        'message_id': 'messageId',
        'webhook_id': 'webhookId',
        'event_name': 'eventName',
        'webhook_name': 'webhookName',
        'ai_transform_result_id': 'aiTransformResultId',
        'user_id': 'userId',
        'ai_transform_id': 'aiTransformId',
        'ai_transform_mapping_id': 'aiTransformMappingId',
        'entity_id': 'entityId',
        'entity_type': 'entityType',
        'result': 'result'
    }

    def __init__(self, message_id=None, webhook_id=None, event_name=None, webhook_name=None, ai_transform_result_id=None, user_id=None, ai_transform_id=None, ai_transform_mapping_id=None, entity_id=None, entity_type=None, result=None, local_vars_configuration=None):  # noqa: E501
        """WebhookNewAITransformResultPayload - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._message_id = None
        self._webhook_id = None
        self._event_name = None
        self._webhook_name = None
        self._ai_transform_result_id = None
        self._user_id = None
        self._ai_transform_id = None
        self._ai_transform_mapping_id = None
        self._entity_id = None
        self._entity_type = None
        self._result = None
        self.discriminator = None

        self.message_id = message_id
        self.webhook_id = webhook_id
        self.event_name = event_name
        self.webhook_name = webhook_name
        self.ai_transform_result_id = ai_transform_result_id
        self.user_id = user_id
        self.ai_transform_id = ai_transform_id
        self.ai_transform_mapping_id = ai_transform_mapping_id
        self.entity_id = entity_id
        self.entity_type = entity_type
        self.result = result

    @property
    def message_id(self):
        """Gets the message_id of this WebhookNewAITransformResultPayload.  # noqa: E501

        Idempotent message ID. Store this ID locally or in a database to prevent message duplication.  # noqa: E501

        :return: The message_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """Sets the message_id of this WebhookNewAITransformResultPayload.

        Idempotent message ID. Store this ID locally or in a database to prevent message duplication.  # noqa: E501

        :param message_id: The message_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and message_id is None:  # noqa: E501
            raise ValueError("Invalid value for `message_id`, must not be `None`")  # noqa: E501

        self._message_id = message_id

    @property
    def webhook_id(self):
        """Gets the webhook_id of this WebhookNewAITransformResultPayload.  # noqa: E501

        ID of webhook entity being triggered  # noqa: E501

        :return: The webhook_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._webhook_id

    @webhook_id.setter
    def webhook_id(self, webhook_id):
        """Sets the webhook_id of this WebhookNewAITransformResultPayload.

        ID of webhook entity being triggered  # noqa: E501

        :param webhook_id: The webhook_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and webhook_id is None:  # noqa: E501
            raise ValueError("Invalid value for `webhook_id`, must not be `None`")  # noqa: E501

        self._webhook_id = webhook_id

    @property
    def event_name(self):
        """Gets the event_name of this WebhookNewAITransformResultPayload.  # noqa: E501

        Name of the event type webhook is being triggered for.  # noqa: E501

        :return: The event_name of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this WebhookNewAITransformResultPayload.

        Name of the event type webhook is being triggered for.  # noqa: E501

        :param event_name: The event_name of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and event_name is None:  # noqa: E501
            raise ValueError("Invalid value for `event_name`, must not be `None`")  # noqa: E501
        allowed_values = ["EMAIL_RECEIVED", "NEW_AI_TRANSFORM_RESULT", "NEW_EMAIL", "NEW_CONTACT", "NEW_ATTACHMENT", "EMAIL_OPENED", "EMAIL_READ", "DELIVERY_STATUS", "BOUNCE", "BOUNCE_RECIPIENT", "NEW_SMS", "NEW_GUEST_USER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and event_name not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `event_name` ({0}), must be one of {1}"  # noqa: E501
                .format(event_name, allowed_values)
            )

        self._event_name = event_name

    @property
    def webhook_name(self):
        """Gets the webhook_name of this WebhookNewAITransformResultPayload.  # noqa: E501

        Name of the webhook being triggered  # noqa: E501

        :return: The webhook_name of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._webhook_name

    @webhook_name.setter
    def webhook_name(self, webhook_name):
        """Sets the webhook_name of this WebhookNewAITransformResultPayload.

        Name of the webhook being triggered  # noqa: E501

        :param webhook_name: The webhook_name of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """

        self._webhook_name = webhook_name

    @property
    def ai_transform_result_id(self):
        """Gets the ai_transform_result_id of this WebhookNewAITransformResultPayload.  # noqa: E501

        AI Transform ID of event  # noqa: E501

        :return: The ai_transform_result_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._ai_transform_result_id

    @ai_transform_result_id.setter
    def ai_transform_result_id(self, ai_transform_result_id):
        """Sets the ai_transform_result_id of this WebhookNewAITransformResultPayload.

        AI Transform ID of event  # noqa: E501

        :param ai_transform_result_id: The ai_transform_result_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and ai_transform_result_id is None:  # noqa: E501
            raise ValueError("Invalid value for `ai_transform_result_id`, must not be `None`")  # noqa: E501

        self._ai_transform_result_id = ai_transform_result_id

    @property
    def user_id(self):
        """Gets the user_id of this WebhookNewAITransformResultPayload.  # noqa: E501

        User ID of event  # noqa: E501

        :return: The user_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this WebhookNewAITransformResultPayload.

        User ID of event  # noqa: E501

        :param user_id: The user_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def ai_transform_id(self):
        """Gets the ai_transform_id of this WebhookNewAITransformResultPayload.  # noqa: E501

        ID of AI Transform  # noqa: E501

        :return: The ai_transform_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._ai_transform_id

    @ai_transform_id.setter
    def ai_transform_id(self, ai_transform_id):
        """Sets the ai_transform_id of this WebhookNewAITransformResultPayload.

        ID of AI Transform  # noqa: E501

        :param ai_transform_id: The ai_transform_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and ai_transform_id is None:  # noqa: E501
            raise ValueError("Invalid value for `ai_transform_id`, must not be `None`")  # noqa: E501

        self._ai_transform_id = ai_transform_id

    @property
    def ai_transform_mapping_id(self):
        """Gets the ai_transform_mapping_id of this WebhookNewAITransformResultPayload.  # noqa: E501

        ID of AI Transform mapping  # noqa: E501

        :return: The ai_transform_mapping_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._ai_transform_mapping_id

    @ai_transform_mapping_id.setter
    def ai_transform_mapping_id(self, ai_transform_mapping_id):
        """Sets the ai_transform_mapping_id of this WebhookNewAITransformResultPayload.

        ID of AI Transform mapping  # noqa: E501

        :param ai_transform_mapping_id: The ai_transform_mapping_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """

        self._ai_transform_mapping_id = ai_transform_mapping_id

    @property
    def entity_id(self):
        """Gets the entity_id of this WebhookNewAITransformResultPayload.  # noqa: E501

        ID of entity that triggered the transformation  # noqa: E501

        :return: The entity_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """Sets the entity_id of this WebhookNewAITransformResultPayload.

        ID of entity that triggered the transformation  # noqa: E501

        :param entity_id: The entity_id of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """

        self._entity_id = entity_id

    @property
    def entity_type(self):
        """Gets the entity_type of this WebhookNewAITransformResultPayload.  # noqa: E501

        Entity type that triggered the transformation  # noqa: E501

        :return: The entity_type of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this WebhookNewAITransformResultPayload.

        Entity type that triggered the transformation  # noqa: E501

        :param entity_type: The entity_type of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"INBOX", "PHONE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and entity_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `entity_type` ({0}), must be one of {1}"  # noqa: E501
                .format(entity_type, allowed_values)
            )

        self._entity_type = entity_type

    @property
    def result(self):
        """Gets the result of this WebhookNewAITransformResultPayload.  # noqa: E501

        JSON string result of the AI transformation  # noqa: E501

        :return: The result of this WebhookNewAITransformResultPayload.  # noqa: E501
        :rtype: str
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this WebhookNewAITransformResultPayload.

        JSON string result of the AI transformation  # noqa: E501

        :param result: The result of this WebhookNewAITransformResultPayload.  # noqa: E501
        :type: str
        """

        self._result = result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookNewAITransformResultPayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebhookNewAITransformResultPayload):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ConnectorSmtpConnectionDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'connector_id': 'str',
        'smtp_host': 'str',
        'smtp_port': 'int',
        'smtp_username': 'str',
        'smtp_password': 'str',
        'smtp_ssl': 'bool',
        'start_tls': 'bool',
        'smtp_mechanisms': 'list[str]',
        'local_host_name': 'str',
        'proxy_host': 'str',
        'proxy_port': 'int',
        'proxy_enabled': 'bool',
        'enabled': 'bool',
        'ssl_trust': 'str',
        'ssl_protocols': 'list[str]',
        'created_at': 'datetime',
        'id': 'str'
    }

    attribute_map = {
        'connector_id': 'connectorId',
        'smtp_host': 'smtpHost',
        'smtp_port': 'smtpPort',
        'smtp_username': 'smtpUsername',
        'smtp_password': 'smtpPassword',
        'smtp_ssl': 'smtpSsl',
        'start_tls': 'startTls',
        'smtp_mechanisms': 'smtpMechanisms',
        'local_host_name': 'localHostName',
        'proxy_host': 'proxyHost',
        'proxy_port': 'proxyPort',
        'proxy_enabled': 'proxyEnabled',
        'enabled': 'enabled',
        'ssl_trust': 'sslTrust',
        'ssl_protocols': 'sslProtocols',
        'created_at': 'createdAt',
        'id': 'id'
    }

    def __init__(self, connector_id=None, smtp_host=None, smtp_port=None, smtp_username=None, smtp_password=None, smtp_ssl=None, start_tls=None, smtp_mechanisms=None, local_host_name=None, proxy_host=None, proxy_port=None, proxy_enabled=None, enabled=None, ssl_trust=None, ssl_protocols=None, created_at=None, id=None, local_vars_configuration=None):  # noqa: E501
        """ConnectorSmtpConnectionDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._connector_id = None
        self._smtp_host = None
        self._smtp_port = None
        self._smtp_username = None
        self._smtp_password = None
        self._smtp_ssl = None
        self._start_tls = None
        self._smtp_mechanisms = None
        self._local_host_name = None
        self._proxy_host = None
        self._proxy_port = None
        self._proxy_enabled = None
        self._enabled = None
        self._ssl_trust = None
        self._ssl_protocols = None
        self._created_at = None
        self._id = None
        self.discriminator = None

        self.connector_id = connector_id
        self.smtp_host = smtp_host
        self.smtp_port = smtp_port
        self.smtp_username = smtp_username
        self.smtp_password = smtp_password
        self.smtp_ssl = smtp_ssl
        self.start_tls = start_tls
        self.smtp_mechanisms = smtp_mechanisms
        self.local_host_name = local_host_name
        self.proxy_host = proxy_host
        self.proxy_port = proxy_port
        self.proxy_enabled = proxy_enabled
        self.enabled = enabled
        self.ssl_trust = ssl_trust
        self.ssl_protocols = ssl_protocols
        self.created_at = created_at
        self.id = id

    @property
    def connector_id(self):
        """Gets the connector_id of this ConnectorSmtpConnectionDto.  # noqa: E501


        :return: The connector_id of this ConnectorSmtpConnectionDto.  # noqa: E501
        :rtype: str
        """
        return self._connector_id

    @connector_id.setter
    def connector_id(self, connector_id):
        """Sets the connector_id of this ConnectorSmtpConnectionDto.


        :param connector_id: The connector_id of this ConnectorSmtpConnectionDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and connector_id is None:  # noqa: E501
            raise ValueError("Invalid value for `connector_id`, must not be `None`")  # noqa: E501

        self._connector_id = connector_id

    @property
    def smtp_host(self):
        """Gets the smtp_host of this ConnectorSmtpConnectionDto.  # noqa: E501


        :return: The smtp_host of this ConnectorSmtpConnectionDto.  # noqa: E501
        :rtype: str
        """
        return self._smtp_host

    @smtp_host.setter
    def smtp_host(self, smtp_host):
        """Sets the smtp_host of this ConnectorSmtpConnectionDto.


        :param smtp_host: The smtp_host of this ConnectorSmtpConnectionDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and smtp_host is None:  # noqa: E501
            raise ValueError("Invalid value for `smtp_host`, must not be `None`")  # noqa: E501

        self._smtp_host = smtp_host

    @property
    def smtp_port(self):
        """Gets the smtp_port of this ConnectorSmtpConnectionDto.  # noqa: E501


        :return: The smtp_port of this ConnectorSmtpConnectionDto.  # noqa: E501
        :rtype: int
        """
        return self._smtp_port

    @smtp_port.setter
    def smtp_port(self, smtp_port):
        """Sets the smtp_port of this ConnectorSmtpConnectionDto.


        :param smtp_port: The smtp_port of this ConnectorSmtpConnectionDto.  # noqa: E501
        :type: int
        """

        self._smtp_port = smtp_port

    @property
    def smtp_username(self):
        """Gets the smtp_username of this ConnectorSmtpConnectionDto.  # noqa: E501


        :return: The smtp_username of this ConnectorSmtpConnectionDto.  # noqa: E501
        :rtype: str
        """
        return self._smtp_username

    @smtp_username.setter
    def smtp_username(self, smtp_username):
        """Sets the smtp_username of this ConnectorSmtpConnectionDto.


        :param smtp_username: The smtp_username of this ConnectorSmtpConnectionDto.  # noqa: E501
        :type: str
        """

        self._smtp_username = smtp_username

    @property
    def smtp_password(self):
        """Gets the smtp_password of this ConnectorSmtpConnectionDto.  # noqa: E501


        :return: The smtp_password of this ConnectorSmtpConnectionDto.  # noqa: E501
        :rtype: str
        """
        return self._smtp_password

    @smtp_password.setter
    def smtp_password(self, smtp_password):
        """Sets the smtp_password of this ConnectorSmtpConnectionDto.


        :param smtp_password: The smtp_password of this ConnectorSmtpConnectionDto.  # noqa: E501
        :type: str
        """

        self._smtp_password = smtp_password

    @property
    def smtp_ssl(self):
        """Gets the smtp_ssl of this ConnectorSmtpConnectionDto.  # noqa: E501


        :return: The smtp_ssl of this ConnectorSmtpConnectionDto.  # noqa: E501
        :rtype: bool
        """
        return self._smtp_ssl

    @smtp_ssl.setter
    def smtp_ssl(self, smtp_ssl):
        """Sets the smtp_ssl of this ConnectorSmtpConnectionDto.


        :param smtp_ssl: The smtp_ssl of this ConnectorSmtpConnectionDto.  # noqa: E501
        :type: bool
        """

        self._smtp_ssl = smtp_ssl

    @property
    def start_tls(self):
        """Gets the start_tls of this ConnectorSmtpConnectionDto.  # noqa: E501


        :return: The start_tls of this ConnectorSmtpConnectionDto.  # noqa: E501
        :rtype: bool
        """
        return self._start_tls

    @start_tls.setter
    def start_tls(self, start_tls):
        """Sets the start_tls of this ConnectorSmtpConnectionDto.


        :param start_tls: The start_tls of this ConnectorSmtpConnectionDto.  # noqa: E501
        :type: bool
        """

        self._start_tls = start_tls

    @property
    def smtp_mechanisms(self):
        """Gets the smtp_mechanisms of this ConnectorSmtpConnectionDto.  # noqa: E501


        :return: The smtp_mechanisms of this ConnectorSmtpConnectionDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._smtp_mechanisms

    @smtp_mechanisms.setter
    def smtp_mechanisms(self, smtp_mechanisms):
        """Sets the smtp_mechanisms of this ConnectorSmtpConnectionDto.


        :param smtp_mechanisms: The smtp_mechanisms of this ConnectorSmtpConnectionDto.  # noqa: E501
        :type: list[str]
        """

        self._smtp_mechanisms = smtp_mechanisms

    @property
    def local_host_name(self):
        """Gets the local_host_name of this ConnectorSmtpConnectionDto.  # noqa: E501


        :return: The local_host_name of this ConnectorSmtpConnectionDto.  # noqa: E501
        :rtype: str
        """
        return self._local_host_name

    @local_host_name.setter
    def local_host_name(self, local_host_name):
        """Sets the local_host_name of this ConnectorSmtpConnectionDto.


        :param local_host_name: The local_host_name of this ConnectorSmtpConnectionDto.  # noqa: E501
        :type: str
        """

        self._local_host_name = local_host_name

    @property
    def proxy_host(self):
        """Gets the proxy_host of this ConnectorSmtpConnectionDto.  # noqa: E501


        :return: The proxy_host of this ConnectorSmtpConnectionDto.  # noqa: E501
        :rtype: str
        """
        return self._proxy_host

    @proxy_host.setter
    def proxy_host(self, proxy_host):
        """Sets the proxy_host of this ConnectorSmtpConnectionDto.


        :param proxy_host: The proxy_host of this ConnectorSmtpConnectionDto.  # noqa: E501
        :type: str
        """

        self._proxy_host = proxy_host

    @property
    def proxy_port(self):
        """Gets the proxy_port of this ConnectorSmtpConnectionDto.  # noqa: E501


        :return: The proxy_port of this ConnectorSmtpConnectionDto.  # noqa: E501
        :rtype: int
        """
        return self._proxy_port

    @proxy_port.setter
    def proxy_port(self, proxy_port):
        """Sets the proxy_port of this ConnectorSmtpConnectionDto.


        :param proxy_port: The proxy_port of this ConnectorSmtpConnectionDto.  # noqa: E501
        :type: int
        """

        self._proxy_port = proxy_port

    @property
    def proxy_enabled(self):
        """Gets the proxy_enabled of this ConnectorSmtpConnectionDto.  # noqa: E501


        :return: The proxy_enabled of this ConnectorSmtpConnectionDto.  # noqa: E501
        :rtype: bool
        """
        return self._proxy_enabled

    @proxy_enabled.setter
    def proxy_enabled(self, proxy_enabled):
        """Sets the proxy_enabled of this ConnectorSmtpConnectionDto.


        :param proxy_enabled: The proxy_enabled of this ConnectorSmtpConnectionDto.  # noqa: E501
        :type: bool
        """

        self._proxy_enabled = proxy_enabled

    @property
    def enabled(self):
        """Gets the enabled of this ConnectorSmtpConnectionDto.  # noqa: E501


        :return: The enabled of this ConnectorSmtpConnectionDto.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this ConnectorSmtpConnectionDto.


        :param enabled: The enabled of this ConnectorSmtpConnectionDto.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def ssl_trust(self):
        """Gets the ssl_trust of this ConnectorSmtpConnectionDto.  # noqa: E501


        :return: The ssl_trust of this ConnectorSmtpConnectionDto.  # noqa: E501
        :rtype: str
        """
        return self._ssl_trust

    @ssl_trust.setter
    def ssl_trust(self, ssl_trust):
        """Sets the ssl_trust of this ConnectorSmtpConnectionDto.


        :param ssl_trust: The ssl_trust of this ConnectorSmtpConnectionDto.  # noqa: E501
        :type: str
        """

        self._ssl_trust = ssl_trust

    @property
    def ssl_protocols(self):
        """Gets the ssl_protocols of this ConnectorSmtpConnectionDto.  # noqa: E501


        :return: The ssl_protocols of this ConnectorSmtpConnectionDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._ssl_protocols

    @ssl_protocols.setter
    def ssl_protocols(self, ssl_protocols):
        """Sets the ssl_protocols of this ConnectorSmtpConnectionDto.


        :param ssl_protocols: The ssl_protocols of this ConnectorSmtpConnectionDto.  # noqa: E501
        :type: list[str]
        """

        self._ssl_protocols = ssl_protocols

    @property
    def created_at(self):
        """Gets the created_at of this ConnectorSmtpConnectionDto.  # noqa: E501


        :return: The created_at of this ConnectorSmtpConnectionDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ConnectorSmtpConnectionDto.


        :param created_at: The created_at of this ConnectorSmtpConnectionDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def id(self):
        """Gets the id of this ConnectorSmtpConnectionDto.  # noqa: E501


        :return: The id of this ConnectorSmtpConnectionDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ConnectorSmtpConnectionDto.


        :param id: The id of this ConnectorSmtpConnectionDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConnectorSmtpConnectionDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConnectorSmtpConnectionDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhoneMessageThreadProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'phone_number': 'str',
        'phone_number_id': 'str',
        'other_phone_number': 'str',
        'last_message_direction': 'str',
        'last_body': 'str',
        'last_created': 'datetime'
    }

    attribute_map = {
        'phone_number': 'phoneNumber',
        'phone_number_id': 'phoneNumberId',
        'other_phone_number': 'otherPhoneNumber',
        'last_message_direction': 'lastMessageDirection',
        'last_body': 'lastBody',
        'last_created': 'lastCreated'
    }

    def __init__(self, phone_number=None, phone_number_id=None, other_phone_number=None, last_message_direction=None, last_body=None, last_created=None, local_vars_configuration=None):  # noqa: E501
        """PhoneMessageThreadProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._phone_number = None
        self._phone_number_id = None
        self._other_phone_number = None
        self._last_message_direction = None
        self._last_body = None
        self._last_created = None
        self.discriminator = None

        if phone_number is not None:
            self.phone_number = phone_number
        self.phone_number_id = phone_number_id
        if other_phone_number is not None:
            self.other_phone_number = other_phone_number
        self.last_message_direction = last_message_direction
        self.last_body = last_body
        self.last_created = last_created

    @property
    def phone_number(self):
        """Gets the phone_number of this PhoneMessageThreadProjection.  # noqa: E501


        :return: The phone_number of this PhoneMessageThreadProjection.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this PhoneMessageThreadProjection.


        :param phone_number: The phone_number of this PhoneMessageThreadProjection.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def phone_number_id(self):
        """Gets the phone_number_id of this PhoneMessageThreadProjection.  # noqa: E501


        :return: The phone_number_id of this PhoneMessageThreadProjection.  # noqa: E501
        :rtype: str
        """
        return self._phone_number_id

    @phone_number_id.setter
    def phone_number_id(self, phone_number_id):
        """Sets the phone_number_id of this PhoneMessageThreadProjection.


        :param phone_number_id: The phone_number_id of this PhoneMessageThreadProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_number_id is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_number_id`, must not be `None`")  # noqa: E501

        self._phone_number_id = phone_number_id

    @property
    def other_phone_number(self):
        """Gets the other_phone_number of this PhoneMessageThreadProjection.  # noqa: E501


        :return: The other_phone_number of this PhoneMessageThreadProjection.  # noqa: E501
        :rtype: str
        """
        return self._other_phone_number

    @other_phone_number.setter
    def other_phone_number(self, other_phone_number):
        """Sets the other_phone_number of this PhoneMessageThreadProjection.


        :param other_phone_number: The other_phone_number of this PhoneMessageThreadProjection.  # noqa: E501
        :type: str
        """

        self._other_phone_number = other_phone_number

    @property
    def last_message_direction(self):
        """Gets the last_message_direction of this PhoneMessageThreadProjection.  # noqa: E501


        :return: The last_message_direction of this PhoneMessageThreadProjection.  # noqa: E501
        :rtype: str
        """
        return self._last_message_direction

    @last_message_direction.setter
    def last_message_direction(self, last_message_direction):
        """Sets the last_message_direction of this PhoneMessageThreadProjection.


        :param last_message_direction: The last_message_direction of this PhoneMessageThreadProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and last_message_direction is None:  # noqa: E501
            raise ValueError("Invalid value for `last_message_direction`, must not be `None`")  # noqa: E501
        allowed_values = ["OUTBOUND", "INBOUND"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and last_message_direction not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `last_message_direction` ({0}), must be one of {1}"  # noqa: E501
                .format(last_message_direction, allowed_values)
            )

        self._last_message_direction = last_message_direction

    @property
    def last_body(self):
        """Gets the last_body of this PhoneMessageThreadProjection.  # noqa: E501


        :return: The last_body of this PhoneMessageThreadProjection.  # noqa: E501
        :rtype: str
        """
        return self._last_body

    @last_body.setter
    def last_body(self, last_body):
        """Sets the last_body of this PhoneMessageThreadProjection.


        :param last_body: The last_body of this PhoneMessageThreadProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and last_body is None:  # noqa: E501
            raise ValueError("Invalid value for `last_body`, must not be `None`")  # noqa: E501

        self._last_body = last_body

    @property
    def last_created(self):
        """Gets the last_created of this PhoneMessageThreadProjection.  # noqa: E501


        :return: The last_created of this PhoneMessageThreadProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._last_created

    @last_created.setter
    def last_created(self, last_created):
        """Sets the last_created of this PhoneMessageThreadProjection.


        :param last_created: The last_created of this PhoneMessageThreadProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and last_created is None:  # noqa: E501
            raise ValueError("Invalid value for `last_created`, must not be `None`")  # noqa: E501

        self._last_created = last_created

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneMessageThreadProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhoneMessageThreadProjection):
            return True

        return self.to_dict() != other.to_dict()
